@@ -1,9 +1,8 @@
 #include <module/Module.h>
 #include "distributions/DWT1.h"
 #include "distributions/DWT2.h"
-#include "distributions/DTboost.h"
-#include "distributions/DWT1boost.h"
-#include "distributions/DWT2boost.h"
+#include "distributions/DWN1.h"
+#include "distributions/DWN2.h"
 #include "functions/LogWeightedtFun.h"
 
 namespace jags { 
@@ -20,9 +19,8 @@ namespace weightedt { // module namespace
   WTModule::WTModule() : Module("RoBMA"){
     insert(new DWT1);
     insert(new DWT2);
-    insert(new DTboost);
-    insert(new DWT1boost);
-    insert(new DWT2boost);
+    insert(new DWN1);
+    insert(new DWN2);
     //load functions
     insert(new LogWeightedtFun);
   }
